package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import javax.accessibility.Accessible;

public class JCheckBoxMenuItem extends JMenuItem implements SwingConstants, Accessible
{
    private static final String uiClassID = "CheckBoxMenuItemUI";
    
    public JCheckBoxMenuItem() {
        this(null, null, false);
    }
    
    public JCheckBoxMenuItem(Icon icon) {
        this(null, icon, false);
    }
    
    public JCheckBoxMenuItem(String s) {
        this(s, null, false);
    }
    
    public JCheckBoxMenuItem(Action action) {
        this();
        this.setAction(action);
    }
    
    public JCheckBoxMenuItem(String s, Icon icon) {
        this(s, icon, false);
    }
    
    public JCheckBoxMenuItem(String s, boolean b) {
        this(s, null, b);
    }
    
    public JCheckBoxMenuItem(String s, Icon icon, boolean selected) {
        super(s, icon);
        this.setModel(new JToggleButton.ToggleButtonModel());
        this.setSelected(selected);
        this.setFocusable(false);
    }
    
    @Override
    public String getUIClassID() {
        return "CheckBoxMenuItemUI";
    }
    
    public boolean getState() {
        return this.isSelected();
    }
    
    public synchronized void setState(boolean selected) {
        this.setSelected(selected);
    }
    
    @Override
    public Object[] getSelectedObjects() {
        if (!this.isSelected()) {
            return null;
        }
        return new Object[] { this.getText() };
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("CheckBoxMenuItemUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString();
    }
    
    @Override
    boolean shouldUpdateSelectedStateFromAction() {
        return true;
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JCheckBoxMenuItem.AccessibleJCheckBoxMenuItem();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleJCheckBoxMenuItem extends JMenuItem.AccessibleJMenuItem
    {
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.CHECK_BOX;
        }
    }
}
